package com.example.bdkipoc;

import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.TextView;

import androidx.annotation.Nullable;
import androidx.appcompat.app.AppCompatActivity;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URI;
import java.net.URL;

public class QrisResultActivity extends AppCompatActivity {
    private ImageView qrImageView;
    private TextView amountTextView;
    private TextView referenceTextView;
    private Button downloadQrisButton;
    private Button checkStatusButton;
    private TextView statusTextView;
    private Button returnMainButton;
    private ProgressBar progressBar;
    private String orderId;
    private String grossAmount;
    private String referenceId;
    private String transactionId;
    private String transactionTime;
    private String acquirer;
    private String merchantId;
    private String backendBase = "https://be-edc.msvc.app";
    private String webhookUrl = "https://be-edc.msvc.app/webhooks/midtrans";

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_qris_result);

        qrImageView = findViewById(R.id.qrImageView);
        amountTextView = findViewById(R.id.amountTextView);
        referenceTextView = findViewById(R.id.referenceTextView);
        downloadQrisButton = findViewById(R.id.downloadQrisButton);
        checkStatusButton = findViewById(R.id.checkStatusButton);
        statusTextView = findViewById(R.id.statusTextView);
        returnMainButton = findViewById(R.id.returnMainButton);
        progressBar = findViewById(R.id.progressBar);

        Intent intent = getIntent();
        String qrImageUrl = intent.getStringExtra("qrImageUrl");
        int amount = intent.getIntExtra("amount", 0);
        referenceId = intent.getStringExtra("referenceId");
        orderId = intent.getStringExtra("orderId");
        grossAmount = intent.getStringExtra("grossAmount");
        transactionId = intent.getStringExtra("transactionId");
        transactionTime = intent.getStringExtra("transactionTime");
        acquirer = intent.getStringExtra("acquirer");
        merchantId = intent.getStringExtra("merchantId");

        if (orderId == null || transactionId == null) {
            Log.e("QrisResultFlow", "orderId or transactionId is null! Intent extras: " + intent.getExtras());
            android.widget.Toast.makeText(this, "Missing transaction details!", android.widget.Toast.LENGTH_LONG).show();
        }

        // Get the exact amount from the grossAmount string value instead of the integer
        String amountStr = "Amount: " + grossAmount;
        amountTextView.setText(amountStr);
        referenceTextView.setText("Reference ID: " + referenceId);

        // Load QR image
        new DownloadImageTask(qrImageView).execute(qrImageUrl);

        // Disable check status button initially
        checkStatusButton.setEnabled(false);
        // Start polling for pending payment log
        pollPendingPaymentLog(orderId);

        // Download QRIS button
        downloadQrisButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                qrImageView.setDrawingCacheEnabled(true);
                Bitmap bitmap = qrImageView.getDrawingCache();
                if (bitmap != null) {
                    saveImageToGallery(bitmap, "qris_code_" + System.currentTimeMillis());
                }
                qrImageView.setDrawingCacheEnabled(false);
            }
        });

        // Check Payment Status button
        checkStatusButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                simulateWebhook();
            }
        });

        // Return to Main Screen button
        returnMainButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(QrisResultActivity.this, com.example.bdkipoc.MainActivity.class);
                intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP | Intent.FLAG_ACTIVITY_NEW_TASK);
                startActivity(intent);
                finishAffinity();
            }
        });
    }

    private static class DownloadImageTask extends AsyncTask<String, Void, Bitmap> {
        ImageView bmImage;
        DownloadImageTask(ImageView bmImage) {
            this.bmImage = bmImage;
        }
        protected Bitmap doInBackground(String... urls) {
            String urlDisplay = urls[0];
            Bitmap bitmap = null;
            try {
                URL url = new URI(urlDisplay).toURL();
                HttpURLConnection connection = (HttpURLConnection) url.openConnection();
                connection.setDoInput(true);
                connection.connect();
                InputStream input = connection.getInputStream();
                bitmap = BitmapFactory.decodeStream(input);
            } catch (Exception e) {
                e.printStackTrace();
            }
            return bitmap;
        }
        protected void onPostExecute(Bitmap result) {
            if (result != null) {
                bmImage.setImageBitmap(result);
            }
        }
    }

    // Save bitmap to gallery
    private void saveImageToGallery(Bitmap bitmap, String fileName) {
        try {
            String savedImageURL = android.provider.MediaStore.Images.Media.insertImage(
                    getContentResolver(), bitmap, fileName, "QRIS Payment QR Code");
            if (savedImageURL != null) {
                android.widget.Toast.makeText(this, "QRIS saved to gallery", android.widget.Toast.LENGTH_SHORT).show();
            } else {
                android.widget.Toast.makeText(this, "Failed to save QRIS", android.widget.Toast.LENGTH_SHORT).show();
            }
        } catch (Exception e) {
            android.widget.Toast.makeText(this, "Error saving QRIS: " + e.getMessage(), android.widget.Toast.LENGTH_LONG).show();
        }
    }

    private void pollPendingPaymentLog(final String orderId) {
        Log.d("QrisResultFlow", "Polling for orderId (transaction_uuid): " + orderId);
        progressBar.setVisibility(View.VISIBLE);
        new Thread(() -> {
            int maxAttempts = 10;
            int intervalMs = 1500;
            int attempt = 0;
            boolean found = false;
            while (attempt < maxAttempts && !found) {
                try {
                    String urlStr = backendBase + "/api-logs?request_body_search_strict={\"order_id\":\"" + orderId + "\"}";
                    Log.d("QrisResultFlow", "Polling URL: " + urlStr);
                    URL url = new URL(urlStr);
                    HttpURLConnection conn = (HttpURLConnection) url.openConnection();
                    conn.setRequestMethod("GET");
                    conn.setRequestProperty("Accept", "application/json");
                    int responseCode = conn.getResponseCode();
                    if (responseCode == 200) {
                        BufferedReader br = new BufferedReader(new InputStreamReader(conn.getInputStream()));
                        StringBuilder response = new StringBuilder();
                        String line;
                        while ((line = br.readLine()) != null) {
                            response.append(line);
                        }
                        JSONObject json = new JSONObject(response.toString());
                        JSONArray results = json.optJSONArray("results");
                        if (results != null && results.length() > 0) {
                            for (int i = 0; i < results.length(); i++) {
                                JSONObject log = results.getJSONObject(i);
                                JSONObject reqBody = log.optJSONObject("request_body");
                                if (reqBody != null && "pending".equals(reqBody.optString("transaction_status"))) {
                                    found = true;
                                    break;
                                }
                            }
                        }
                    }
                } catch (Exception e) {
                    Log.e("QrisResultFlow", "Polling error: " + e.getMessage(), e);
                }
                if (!found) {
                    attempt++;
                    try { Thread.sleep(intervalMs); } catch (InterruptedException ignored) {}
                }
            }
            final boolean logFound = found;
            new Handler(Looper.getMainLooper()).post(() -> {
                progressBar.setVisibility(View.GONE);
                if (logFound) {
                    checkStatusButton.setEnabled(true);
                    android.widget.Toast.makeText(QrisResultActivity.this, "Pending payment log found!", android.widget.Toast.LENGTH_SHORT).show();
                } else {
                    android.widget.Toast.makeText(QrisResultActivity.this, "Pending payment log NOT found.", android.widget.Toast.LENGTH_LONG).show();
                }
            });
        }).start();
    }

    // Simulate webhook callback
    private void simulateWebhook() {
        progressBar.setVisibility(View.VISIBLE);
        new Thread(() -> {
            try {
                JSONObject payload = new JSONObject();
                payload.put("transaction_type", "on-us");
                payload.put("transaction_time", transactionTime != null ? transactionTime : "2025-04-16T06:00:00Z");
                payload.put("transaction_status", "settlement");
                payload.put("transaction_id", transactionId); // Use the actual transaction_id
                payload.put("status_message", "midtrans payment notification");
                payload.put("status_code", "200");
                payload.put("signature_key", "dummy_signature");
                payload.put("settlement_time", transactionTime != null ? transactionTime : "2025-04-16T06:00:00Z");
                payload.put("payment_type", "qris");
                payload.put("order_id", orderId); // Use order_id
                payload.put("merchant_id", merchantId != null ? merchantId : "DUMMY_MERCHANT_ID");
                payload.put("issuer", acquirer != null ? acquirer : "gopay");
                payload.put("gross_amount", grossAmount); // Use exact gross amount
                payload.put("fraud_status", "accept");
                payload.put("currency", "IDR");
                payload.put("acquirer", acquirer != null ? acquirer : "gopay");
                payload.put("shopeepay_reference_number", "");
                payload.put("reference_id", referenceId != null ? referenceId : "DUMMY_REFERENCE_ID");
                Log.d("QrisResultFlow", "Webhook payload: " + payload.toString());

                URL url = new URL(webhookUrl);
                HttpURLConnection conn = (HttpURLConnection) url.openConnection();
                conn.setRequestMethod("POST");
                conn.setRequestProperty("Content-Type", "application/json");
                conn.setDoOutput(true);
                OutputStream os = conn.getOutputStream();
                os.write(payload.toString().getBytes());
                os.flush();
                os.close();
                int responseCode = conn.getResponseCode();
                BufferedReader br = new BufferedReader(new InputStreamReader(
                        responseCode < 400 ? conn.getInputStream() : conn.getErrorStream()));
                StringBuilder response = new StringBuilder();
                String line;
                while ((line = br.readLine()) != null) {
                    response.append(line);
                }
                Log.d("QrisResultFlow", "Webhook response: " + response.toString());
            } catch (Exception e) {
                Log.e("QrisResultFlow", "Webhook error: " + e.getMessage(), e);
            }
            new Handler(Looper.getMainLooper()).post(() -> {
                progressBar.setVisibility(View.GONE);
                // Proceed to show status/result
                qrImageView.setVisibility(View.GONE);
                amountTextView.setVisibility(View.GONE);
                referenceTextView.setVisibility(View.GONE);
                downloadQrisButton.setVisibility(View.GONE);
                checkStatusButton.setVisibility(View.GONE);
                statusTextView.setVisibility(View.VISIBLE);
                returnMainButton.setVisibility(View.VISIBLE);
            });
        }).start();
    }
}
