package com.example.bdkipoc;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import java.util.List;
import java.text.NumberFormat;
import java.util.Locale;

public class TransactionAdapter extends RecyclerView.Adapter<TransactionAdapter.TransactionViewHolder> {
    private List<TransactionActivity.Transaction> transactionList;

    public TransactionAdapter(List<TransactionActivity.Transaction> transactionList) {
        this.transactionList = transactionList;
    }

    @NonNull
    @Override
    public TransactionViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_transaction, parent, false);
        return new TransactionViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull TransactionViewHolder holder, int position) {
        TransactionActivity.Transaction t = transactionList.get(position);
        
        // Format the amount as Indonesian Rupiah
        try {
            double amountValue = Double.parseDouble(t.amount);
            NumberFormat rupiahFormat = NumberFormat.getCurrencyInstance(new Locale.Builder().setLanguage("id").setRegion("ID").build());
            holder.amount.setText(rupiahFormat.format(amountValue));
        } catch (NumberFormatException e) {
            holder.amount.setText("Rp " + t.amount);
        }
        
        holder.status.setText(t.status);
        holder.referenceId.setText(t.referenceId);
        holder.merchantName.setText(t.merchantName);
        holder.createdAt.setText(t.createdAt.replace("T", " ").substring(0, 19));
    }

    @Override
    public int getItemCount() {
        return transactionList.size();
    }

    static class TransactionViewHolder extends RecyclerView.ViewHolder {
        TextView amount, status, referenceId, merchantName, createdAt;
        public TransactionViewHolder(@NonNull View itemView) {
            super(itemView);
            amount = itemView.findViewById(R.id.textAmount);
            status = itemView.findViewById(R.id.textStatus);
            referenceId = itemView.findViewById(R.id.textReferenceId);
            merchantName = itemView.findViewById(R.id.textMerchantName);
            createdAt = itemView.findViewById(R.id.textCreatedAt);
        }
    }
}
